Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/owncloud/client.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorChristian Kamm <mail@ckamm.de>2018-05-18 09:29:40 +0300
committerckamm <mail@ckamm.de>2018-05-23 10:57:00 +0300
commit8f9f2b546277898ea602ae40f639e4b58e413fe5 (patch)
treee2cfa3ebe6f09e39f68104d90ed942c954569b00 /src/gui/application.h
parent70b1deb2262e440753b02d56a2390e0a407aba4a (diff)
Rename Placeholders to Virtual Files in code #6531
Diffstat (limited to 'src/gui/application.h')
-rw-r--r--src/gui/application.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/gui/application.h b/src/gui/application.h
index 3857cc3e7..a3fa9be79 100644
--- a/src/gui/application.h
+++ b/src/gui/application.h
@@ -73,10 +73,10 @@ public slots:
void slotownCloudWizardDone(int);
void slotCrash();
/**
* Will download a placeholder file, and open the result.
* The argument is the filename of the placeholder file (including the extension)
*/
- void openPlaceholder(const QString &filename);
+ void openVirtualFile(const QString &filename);
protected:
void parseOptions(const QStringList &);
@@ -73,10 +73,10 @@ public slots:
void slotCrash();
/**
- * Will download a placeholder file, and open the result.
- * The argument is the filename of the placeholder file (including the extension)
+ * Will download a virtual file, and open the result.
+ * The argument is the filename of the virtual file (including the extension)
*/